@@ -6,7 +6,7 @@ use Poz::Builder;
 use Exporter 'import';
 use Carp;
 
-our $VERSION = "0.15";
+our $VERSION = "0.16";
 
 our @EXPORT_OK = qw/z/;
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
@@ -78,7 +78,20 @@ Poz - A simple, composable, and extensible data validation library for Perl.
     my $book1 = $bookSchema->parse({title => "Perl Best Practices", author => "Damian Conway", published => "2005-07-01"});
     my $book2 = $bookSchema->parse({title => "Spidering Hacks", author => "Kevin Hemenway", published => "2003-10-01"});
     my $bookArray = $bookArraySchema->parse([$book1, $book2]);
-    
+
+    # or use Poz as class builder    
+    {
+        package My::Class;
+        use Poz qw/z/;
+        z->object({
+            name => z->string,
+            age => z->number,
+        })->constructor;
+    }
+    my $instance = My::Class->new(
+        name => 'Alice',
+        age => 20,
+    ); # bless({name => 'Alice', age => 20}, 'My::Class');
     
 =head1 DESCRIPTION
 
@@ -132,6 +145,17 @@ Creates a new date schema object.
 
 Creates a new object schema object.
 
+=head2 z->object(...)->constructor
+
+    package My::Class;
+    use Poz qw/z/;
+    z->object({
+        name => z->string,
+        age => z->number,
+    })->constructor;
+
+Creates a constructor method with Poz validation in your class.
+
 =head2 z->array
 
     my $schema = z->array($schema);
